@@ -163,6 +163,36 @@ class ClientRAIDManagementTestCase(base.BaseTest):
         self.assertIn(expected_virtual_disk,
                       self.drac_client.list_virtual_disks())
 
+    @mock.patch.object(dracclient.client.WSManClient,
+                       'wait_until_idrac_is_ready', spec_set=True,
+                       autospec=True)
+    def test_list_virtual_disks_with_raid_status_change(
+            self, mock_requests, mock_wait_until_idrac_is_ready):
+        expected_virtual_disk = raid.VirtualDisk(
+            id='Disk.Virtual.0:RAID.Integrated.1-1',
+            name='disk 0',
+            description='Virtual Disk 0 on Integrated RAID Controller 1',
+            controller='RAID.Integrated.1-1',
+            raid_level='1',
+            size_mb=571776,
+            status='ok',
+            raid_status='online',
+            span_depth=1,
+            span_length=2,
+            pending_operations=None,
+            physical_disks=[
+                'Disk.Bay.4:Enclosure.Internal.0-1:RAID.Integrated.1-1',
+                'Disk.Bay.5:Enclosure.Internal.0-1:RAID.Integrated.1-1'
+            ])
+
+        mock_requests.post(
+            'https://1.2.3.4:443/wsman',
+            text=test_utils.RAIDEnumerations[
+                uris.DCIM_VirtualDiskView]['Raid_Status_ok'])
+
+        self.assertIn(expected_virtual_disk,
+                      self.drac_client.list_virtual_disks())
+
     @mock.patch.object(dracclient.client.WSManClient,
                        'wait_until_idrac_is_ready', spec_set=True,
                        autospec=True)
